@@ -20,6 +20,7 @@ from datetime  import datetime
 from threading import Thread
 from queue import LifoQueue
 from argparse import ArgumentParser
+from distutils.sysconfig import get_python_lib
 from noted.modules.transferbroker import TransferBroker # TransferBroker class
 
 pd.set_option('display.max_rows', None, 'display.max_columns', None)
@@ -541,7 +542,7 @@ def main():
     logging.getLogger('numexpr.utils').setLevel(logging.WARNING) # hide logging messages from numexpr.utils module
     # Config parser
     params = configparser.ConfigParser(interpolation = configparser.ExtendedInterpolation())
-    params.read(''.join([os.path.dirname, os.path.realpath(__file__), '/params/params.ini']))
+    params.read(''.join([get_python_lib(), '/params/params.ini']))
     print('holii ', ''.join([os.path.dirname, os.path.realpath(__file__), '/params/params.ini']))
     # Argument parser
     args_parser = ArgumentParser(description = 'NOTED: a framework to optimise network traffic via the analysis of data from File Transfer Services.')
